import Aegis from 'aegis-mp-sdk'
import {formatTime} from '../utils/common'


const aegis = new Aegis({
  id: 'iHWefAYqxoRsFYGQvR', // 项目ID，即上报id
})


const LOGLEVEL = {
  LOG: 0,
  INFO: 1,
  DEBUG: 2,
  WARN: 3,
  ERROR: 4, // 无日志记录级别，sdk将不打印任何日志
  NON_LOGGING: 5, // 无日志记录级别，sdk将不打印任何日志
}
export class Logger {
  private logLevel = 0

  private sdkAppId

  private userId

  private roomId

  private TAG_NAME = ''

  constructor(tagName?: string) {
    this.TAG_NAME = tagName || '[TRTCCloud-WX]'
  }

  private loggerInfo(...args: any): void {
    if (Number(this.sdkAppId) !== 1400188366 && Number(this.sdkAppId) !== 1400704311) return
    aegis.infoAll({
      msg: `sdkAppId=${this.sdkAppId}、roomId=${this.roomId}、userId=${this.userId}
${String(args)}`,
      ext1: this.sdkAppId,
      ext2: this.roomId,
      ext3: this.userId
    })
  }

  setInfo(params: {
    sdkAppId: number | string;
    userId: string;
    roomId: string | number;
  }): void {
    const {sdkAppId, userId, roomId} = params
    this.sdkAppId = sdkAppId
    this.userId = userId
    this.roomId = roomId
  }

  setLogLevel(level: number): void {
    this.logLevel = level
  }

  // 打印普通日志
  log(...args: any): void {
    if (this.logLevel === LOGLEVEL.LOG) {
      console.log(this.TAG_NAME, formatTime(), ...args)
      this.loggerInfo(this.TAG_NAME, formatTime(), ...args)
    }
  }

  info(...args: any): void {
    if (this.logLevel <= LOGLEVEL.INFO) {
      console.info(this.TAG_NAME, formatTime(), ...args)
      this.loggerInfo(this.TAG_NAME, formatTime(), ...args)
    }
  }

  // 打印告警日志
  warn(...args: any): void {
    // SDK 上报的相关事件
    if (this.logLevel <= LOGLEVEL.WARN) {
      console.warn(this.TAG_NAME, formatTime(), ...args)
      this.loggerInfo(this.TAG_NAME, formatTime(), ...args)
    }
  }

  // 打印错误日志
  error(...args: any): void {
    // 状态机内部错误信息
    if (this.logLevel <= LOGLEVEL.ERROR) {
      console.error(this.TAG_NAME, formatTime(), ...args)
      this.loggerInfo(this.TAG_NAME, formatTime(), ...args)
    }
  }

  debug(...args: any): void {
    // 状态机内部错误信息
    if (this.logLevel <= LOGLEVEL.DEBUG) {
      console.debug(this.TAG_NAME, formatTime(), ...args)
      this.loggerInfo(this.TAG_NAME, formatTime(), ...args)
    }
  }
}

export const logger = new Logger()

export default logger
