export const uniqueFunc = (arr, uniId) => {
  const res = new Map()
  return arr.filter((item) => !res.has(item[uniId]) && res.set(item[uniId], 1))
}

export const isFunction = (param: any) => typeof param === 'function'
export const isUndefined = (param: any) => typeof param === 'undefined'
export const isString = (param: any) => typeof param === 'string'
export const isNumber = (param: any) => typeof param === 'number'
export const isBoolean = (param: any) => typeof param === 'boolean'

/**
 * 安全执行 JSON.parse
 * @param data
 * @returns
 */
export function safelyParse(data: string) {
  if (typeof data !== 'string') {
    return data
  }
  let result
  try {
    const tempData = JSON.parse(data)
    // 规避 JSON.parse('12345') 转化为 12345 的情况
    if (typeof tempData === 'object' && tempData) {
      result = tempData
    } else {
      result = data
    }
  } catch (error) {
    result = data
  }
  return result
}

export const formatTime = (): string => {
  const timestamp = new Date().getTime()
  const date = new Date(timestamp)
  // const year = date.getFullYear()
  // const month = date.getMonth() + 1
  // const day = date.getDate()
  let hour = date.getHours() as any
  let minute = date.getMinutes() as any
  let second = date.getSeconds() as any
  const millisecond = date.getMilliseconds()
  hour = hour < 10 ? `0${hour}` : hour
  minute = minute < 10 ? `0${minute}` : minute
  second = second < 10 ? `0${second}` : second
  return `${hour}:${minute}:${second}.${millisecond}`
}

export function debounce(func: (...args: any[]) => void, wait: number): (...args: any[]) => void {
  let timeout: ReturnType<typeof setTimeout> | null = null

  return (...args: any[]) => {
    // 清除上一次的定时器
    if (timeout) {
      clearTimeout(timeout)
    }

    // 设置一个新的定时器，在 wait 毫秒后执行原函数
    timeout = setTimeout(() => {
      func(...args)
      timeout = null
    }, wait)
  }
}
