import {
  TRTCAppScene,
  TRTCBeautyStyle,
  TRTCVideoFillMode,
  TRTCVideoMirrorType,
  TRTCVideoResolution,
  TRTCVideoResolutionMode,
  TRTCVideoRotation,
  TRTCVideoStreamType,
} from '../interface'

export const translateTRTCAppScene = (scene: TRTCAppScene): string => {
  switch (scene) {
    case 0:
      return 'videocall'
    case 1:
      return 'live'
    case 2:
      return 'audiocall'
    case 3:
      return 'voicechatroom'
    default:
      return ''
  }
}

export const translateTRTCVideoStreamType = (
  streamType: TRTCVideoStreamType
): string => {
  switch (streamType) {
    case 0:
      return 'main'
    case 1:
      return 'small'
    case 2:
      return 'aux'
    default:
      return ''
  }
}

export const translateTRTCStreamId = (
  userId: string,
  streamType: TRTCVideoStreamType
): string => `${userId}_${translateTRTCVideoStreamType(streamType)}`

const TRTCVideoResolutionMap = {
  [TRTCVideoResolution.TRTCVideoResolution_120_120]: [120, 120],
  [TRTCVideoResolution.TRTCVideoResolution_160_160]: [160, 160],
  [TRTCVideoResolution.TRTCVideoResolution_270_270]: [270, 270],
  [TRTCVideoResolution.TRTCVideoResolution_480_480]: [480, 480],
  [TRTCVideoResolution.TRTCVideoResolution_160_120]: [160, 120],
  [TRTCVideoResolution.TRTCVideoResolution_240_180]: [240, 180],
  [TRTCVideoResolution.TRTCVideoResolution_280_210]: [280, 210],
  [TRTCVideoResolution.TRTCVideoResolution_320_240]: [320, 240],
  [TRTCVideoResolution.TRTCVideoResolution_400_300]: [400, 300],
  [TRTCVideoResolution.TRTCVideoResolution_480_360]: [480, 360],
  [TRTCVideoResolution.TRTCVideoResolution_640_480]: [640, 480],
  [TRTCVideoResolution.TRTCVideoResolution_960_720]: [960, 720],
  [TRTCVideoResolution.TRTCVideoResolution_160_90]: [160, 90],
  [TRTCVideoResolution.TRTCVideoResolution_256_144]: [256, 144],
  [TRTCVideoResolution.TRTCVideoResolution_320_180]: [320, 180],
  [TRTCVideoResolution.TRTCVideoResolution_480_270]: [480, 270],
  [TRTCVideoResolution.TRTCVideoResolution_640_360]: [640, 360],
  [TRTCVideoResolution.TRTCVideoResolution_960_540]: [960, 540],
  [TRTCVideoResolution.TRTCVideoResolution_1280_720]: [1280, 720],
  [TRTCVideoResolution.TRTCVideoResolution_1920_1080]: [1920, 1080],
}
export const translateTRTCVideoResolution = (
  resolution: TRTCVideoResolution
): Record<'videoWidth' | 'videoHeight', number> => {
  const [videoWidth = 0, videoHeight = 0] = TRTCVideoResolutionMap[resolution]
  return {videoWidth, videoHeight}
}

export const translateTRTCVideoResolutionMode = (
  resolutionMode: TRTCVideoResolutionMode
): string => {
  switch (resolutionMode) {
    case TRTCVideoResolutionMode.TRTCVideoResolutionModeLandscape:
      return 'horizontal'
    case TRTCVideoResolutionMode.TRTCVideoResolutionModePortrait:
      return 'vertical'
    default:
      return ''
  }
}

export const translateTRTCVideoRotation = (rotation: TRTCVideoRotation): string => {
  switch (rotation) {
    case TRTCVideoRotation.TRTCVideoRotation0:
      return 'vertical'
    case TRTCVideoRotation.TRTCVideoRotation90:
      return 'horizontal'
    default:
      return ''
  }
}

export const translateTRTCVideoMirrorType = (
  mirrorType: TRTCVideoMirrorType
): string => {
  switch (mirrorType) {
    case TRTCVideoMirrorType.TRTCVideoMirrorType_Auto:
      return 'auto'
    case TRTCVideoMirrorType.TRTCVideoMirrorType_Enable:
      return 'enable'
    case TRTCVideoMirrorType.TRTCVideoMirrorType_Disable:
      return 'disable'
    default:
      return ''
  }
}

const TRTCBeautyStyleMap = {
  [TRTCBeautyStyle.TRTCBeautyStyleSmooth]: 'smooth',
  [TRTCBeautyStyle.TRTCBeautyStyleNature]: 'nature'
}
export const translateBeautyStyle = (beautyStyle: TRTCBeautyStyle): string => TRTCBeautyStyleMap[beautyStyle]

const TRTCVideoFillModeMap = {
  [TRTCVideoFillMode.TRTCVideoFillMode_Fill]: 'fillCrop',
  [TRTCVideoFillMode.TRTCVideoFillMode_Fit]: 'contain'
}
export const translateVideoFillMod = (videoFillMod: TRTCVideoFillMode): string => TRTCVideoFillModeMap[videoFillMod]
